from setuptools import setup

setup(
    name = 'salabim',
    packages = ['salabim'],
    version = '2.3.3',
    include_package_data=True,
    long_description = 'salabim\n\nsalabim is a discrete event simulation package in Python\nwith builtin *animation*.',
    description = 'discrete event simulation in Python',
    author = 'Ruud van der Ham',
    author_email = 'info@salabim.org',
    url = 'https://github.com/salabim/salabim',
    download_url = 'https://github.com/salabim/salabim',
    keywords = ['statistics', 'math','simulation','des','discrete event simulation'],
    classifiers = []
)
